******************************************************************************************************************
*****	Household Business Performance in Ghana: The Role of Personality Traits and Gender Role Attitudes	******
******************************	Data Preparation Dofile ********************************

****************************************** DATA PREPARATION ************************************************

	//	Set up System
		set more off
		capture set max_memory 500M /* for stata 12 */
		capture set mem 500M		
		cap log close
		clear all
		

	//	SALIENT VARIABLES
		use "$data/sec6_nfe.dta", clear
		merge m:1 hhid using "$data/sec_cover.dta"
		drop _merge

		rename s6q7__0 indiv
		merge m:1 hhid indiv using "$data/sec1_roster.dta"
		keep if _merge==3
		drop _merge

		*Duration of enterprise
		gen ent_tenure= s6q10
		replace ent_tenure= s6q10b if ent_tenure==.
		tab ent_tenure
		gen tenure_sq= ent_tenure* ent_tenure

		*Location of business
		replace s6q15=. if s6q15==96
		label li s6q15
		gen location=1 if s6q15==1 | s6q15==2   //home
		replace location=2 if s6q15==4   // traditional market
		replace location=3 if s6q15==3 | s6q15==5    //industrial/commercial
		replace location=4 if s6q15==6 | s6q15==7     //roadside/other fixed location
		replace location=5 if s6q15==8    //mobile market

		*Other locations
		sort s6q15_os
		tab s6q15_os
		replace location= 2 if s6q15_os== "Abator"
		replace location= 4 if s6q15_os== "Employers home"
		replace location= 4 if s6q15_os== "GOVERNMENT SCHOOL"
		replace location= 2 if s6q15_os== "Jimle Market"
		replace location= 5 if s6q15_os== "NO FIXED LOCATION"
		replace location= 4 if s6q15_os== "PREMPEH CAMPUS"
		replace location= 4 if s6q15_os== "school"

		tab location, gen (l)
		rename l1 home
		rename l2 trad_market
		rename l3 commercial
		rename l4 roadside
		rename l5 mobile 

		tab location

		label var ent_tenure "length of operation of business- closed or open"
		label var location "location of business"
		label var home "business located at home or near home"
		label var trad_market "business located in a traditional market"
		label var commercial "business located in a commercial or industrial area"
		label var roadside "business located by the road or some other fixed place"
		label var mobile "business is mobile with no fixed location"

		*Business registration
		gen registered=1 if s6q20__1==1    // Registrar General
		replace registered= 1 if s6q20__2==1   //Dept of Cooperatives
		replace registered=1 if s6q20__3==1   //District Assembly
		replace registered=1 if s6q20__4==1   //Ghana Revenue authority
		replace registered=1 if s6q20__96==1   //other
		replace registered= 0 if registered==.
		replace registered=. if s6q20__1==. & s6q20__2==. & s6q20__3==. & s6q20__4==. & s6q20__96==.
		tab registered
		label var registered "business is registered"

		*Employees in past 12mnonths
		egen total_emp= rowtotal (s6q24a s6q24b s6q24c s6q24d s6q24e s6q24f), missing   //all workers
		label var total_emp "total workers- paid/unpaid; family/non-family; male/female"

		egen paid_emp= rowtotal (s6q24a s6q24b s6q24c s6q24d), missing   //paid workers
		label var paid_emp "paid workers- male and female family and non-family"

		egen unpaid_emp= rowtotal (s6q24e s6q24f), missing   //unpaid workers
		label var unpaid_emp "unpaid workers- male and female family"

		*Separate household and business expenses
		label li s6q29
		gen sep_exp= 1 if s6q29==1
		replace sep_exp=0 if s6q29==2
		tab s6q29 sep_exp
		label var sep_exp "home and business expenses kept separately"

		*Past experience
		tab s6q36
		gen past_exp=1 if s6q36==1
		replace past_exp=0 if s6q36==2
		tab s6q36 past_exp
		label var past_exp "owner worked as apprentice in this line of work"

		*Operate business with credit?
		gen credit_operate=1 if s6q42==1
		replace credit_operate=0 if s6q42==2
		tab credit_operate
		label var credit_operate "operated NFE with credit in past year"

		*Sought credit to operate business
		tab s6q43
		gen credit_sought=1 if s6q43==1 | s6q43==2
		replace credit_sought=0 if s6q43==3
		tab s6q43 credit_sought 
		label var credit_sought "sought credit to operate NFE in past year"

		*Capital stock
		tab s6q50
		su s6q50
		winsor s6q50, p(.01) gen(s6q50_w1) highonly
		tab s6q50_w1
		su s6q50_w1

		gen capital_stockGHC= s6q50_w1
		gen capital_stock= ln(capital_stockGHC + 1)
		hist capital_stock
		label var capital_stock "value of all NFE capital stock (GHC)- logged"
		label var capital_stockGHC "value of all NFE capital stock (GHC)"

		*Sales revenue 
		tab s6q51
		su s6q51
		winsor s6q51, p(.01) gen(s6q51_w1) highonly
		tab s6q51_w1
		su s6q51_w1

		gen revenueGHC= s6q51_w1
		gen avg_revenueGHC= revenueGHC/ (total_emp+1)  
		replace avg_revenueGHC=0 if avg_revenueGHC==. & total_emp==0

		tab avg_revenueGHC
		hist avg_revenueGHC
		gen avg_revenue= ln(avg_revenueGHC + 1)
		hist avg_revenue

		gen revenue= ln(revenueGHC + 1)
		tab revenue
		hist revenue
		label var revenue "NFE total revenue in last month (GHC)- logged"
		label var revenueGHC "NFE total revenue in last month (GHC)"
		label var avg_revenue "Log Labor Producivity - Total revenue in last month (GHC)/ total number of workers"
		label var avg_revenueGHC "Labor Producivity - Total revenue in last month (GHC)/ total number of workers"

		*Good produced for subsistence
		gen subsist=1 if s6q54==1
		replace subsist=0 if s6q54==2
		tab s6q54 subsist
		label var subsist "Some of produced goods consumed in household last month"

		*Total business costs
		egen costsGHC= rowtotal (s6q56a s6q56c), missing
		tab costsGHC
		gen total_costs= ln(costs + 1)
		tab total_costs
		hist total_costs
		label var total_costs "Sum of salaries and other costs last month (GHC)- logged"
		label var costs "Sum of salaries and other costs last month- GHC"

		*Total profits 
		tab s6q57
		su s6q57

		winsor s6q57, p(.01) gen(s6q57_w1) highonly
		tab s6q57_w1
		su s6q57_w1

		gen profitGHC= s6q57_w1
		hist profitGHC
		gen profit= ln(profitGHC + 1)
		hist profit
		label var profit "NFE profits in last month (GHC)- logged"
		label var profitGHC "NFE profits in last month (GHC)"

		*Own NFE bank account
		label li s6q58
		replace s6q58=. if s6q58==98
		gen NFE_acct=1 if s6q58==1
		replace NFE_acct=0 if s6q58==2
		tab s6q58 NFE_acct
		label var NFE_acct "Owner has bank account for NFE"

		*Seperate NFE and household bank account
		label li s6q59
		tab s6q59
		replace s6q59=. if s6q59==98
		gen NFE_sepacct=1 if s6q59==1
		replace NFE_sepacct=0 if s6q59==2
		tab s6q59 NFE_sepacct
		label var NFE_sepacct "Owner has bank account for NFE"

		*COVID support
		label li s6q60
		replace s6q60=. if s6q60==98
		gen covid_support=1 if s6q60==1
		replace covid_support=0 if s6q60==2
		tab s6q60 covid_support
		label var covid_support "NFE received govt support during COVID"

		*Generator
		label li s6q65
		gen genset=1 if s6q65==1
		replace genset=0 if s6q65==2
		tab s6q65 genset
		label var genset "NFE uses a generator"

		*Worker literacy
		tab s6q66a
		tab s6q66b
		egen NFE_literacy= rowtotal (s6q66a s6q66b), missing
		label var NFE_literacy "NFE workers who can read OR write"

		*Social media
		gen social_media=1 if s6q68==1
		replace social_media=0 if s6q68==2
		tab social_media
		label var social_media "NFE uses social media to operate NFE"

		*Technology
		gen NFE_tech=1 if s6q67a==1 | s6q67b==1
		replace NFE_tech=0 if s6q67a==2 & s6q67b==2
		tab NFE_tech
		label var NFE_tech "NFE currently uses computers OR smartphones"

		*Business association
		label li s6q70
		gen business_assoc=1 if s6q70==1
		replace business_assoc=0 if s6q70==2 | s6q70==3 | s6q70==98
		tab s6q70 business_assoc
		label var business_assoc "NFE belongs to a business association"

		*Number of businesses operating
		bys hhid: egen NFE_number=max(non_farm_enterprise__id) 

		**The spouse works in the business (s6q25a)
		tab s6q25a__0
		tab  s1q5 s6q25a__0
		gen spouse_worked=1 if s1q5==2  & s6q25a__0==1 
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==2
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==3
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==4
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==5
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==6
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==7
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==8
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==9
		replace spouse_worked=1 if s1q5==2  & s6q25a__0==10
		replace spouse_worked=0 if s1q5!=2 & s6q25a__0!=.
		tab spouse_worked

		*Major constraint faced
		*Electricity
		gen elec_constraint= 1 if s6q9__1!=0 &s6q9__1!=.
		replace elec_constraint=0 if s6q9__1==0
		tab s6q9__1 elec_constraint

		*Social network
		gen social_network= 1 if s6q9__2!=0 &s6q9__2!=.
		replace social_network=0 if s6q9__2==0
		tab s6q9__2 social_network

		*Transportation
		gen transport= 1 if s6q9__3!=0 &s6q9__3!=.
		replace transport=0 if s6q9__3==0
		tab s6q9__3 transport

		*Unable to borrow money
		gen borrow_unable= 1 if s6q9__4!=0 &s6q9__4!=.
		replace borrow_unable=0 if s6q9__4==0
		tab s6q9__4 borrow_unable

		*Unwilling to borrow money
		gen borrow_unwilling= 1 if s6q9__5!=0 &s6q9__5!=.
		replace borrow_unwilling=0 if s6q9__5==0
		tab s6q9__5 borrow_unwilling

		*High interest
		gen high_interest= 1 if s6q9__6!=0 &s6q9__6!=.
		replace high_interest=0 if s6q9__6==0
		tab s6q9__6 high_interest

		*Access to markets
		gen market_access= 1 if s6q9__7!=0 &s6q9__7!=.
		replace market_access=0 if s6q9__7==0
		tab s6q9__7 market_access

		*Low demand
		gen demand_low= 1 if s6q9__8!=0 &s6q9__8!=.
		replace demand_low=0 if s6q9__8==0
		tab s6q9__8 demand_low

		*Corruption
		gen corruption= 1 if s6q9__9!=0 &s6q9__9!=.
		replace corruption=0 if s6q9__9==0
		tab s6q9__9 corruption

		*Uncertain economic policy
		gen policy_uncertainty= 1 if s6q9__10!=0 &s6q9__10!=.
		replace policy_uncertainty=0 if s6q9__10==0
		tab s6q9__10 policy_uncertainty

		*Registration and permits
		gen registration_diff= 1 if s6q9__11!=0 &s6q9__11!=.
		replace registration_diff=0 if s6q9__11==0
		tab s6q9__11 registration_diff

		*high taxes
		gen high_taxes= 1 if s6q9__12!=0 &s6q9__12!=.
		replace high_taxes=0 if s6q9__12==0
		tab s6q9__12 high_taxes

		*Criminality, theft and lawlessness
		gen lawlessness= 1 if s6q9__13!=0 &s6q9__13!=.
		replace lawlessness=0 if s6q9__13==0
		tab s6q9__13 lawlessness

		*Conflicts and Social friction
		gen conflicts= 1 if s6q9__14!=0 &s6q9__14!=.
		replace conflicts=0 if s6q9__14==0
		tab s6q9__14 conflicts

		*Internet connectivity
		gen internet_difficult= 1 if s6q9__15!=0 &s6q9__15!=.
		replace internet_difficult=0 if s6q9__15==0
		tab s6q9__15 internet_difficult

		*Lack of equipment
		gen equipment_shortages= 1 if s6q9__16!=0 &s6q9__16!=.
		replace equipment_shortages=0 if s6q9__16==0
		tab s6q9__16 equipment_shortages

		*Other constaints
		gen constraints_other= 1 if s6q9__96!=0 &s6q9__96!=.
		replace constraints_other=0 if s6q9__96==0
		tab s6q9__96 constraints_other


		* Prevalence of constraints
		*weights applied
		estimates clear
		eststo: quietly estpost summarize elec_constraint social_network transport borrow_unable borrow_unwilling high_interest market_access demand_low corruption policy_uncertainty registration_diff high_taxes lawlessness conflicts internet_difficult equipment_shortages constraints_other [aw= hhweight]
		esttab using Contraints, tab replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") label nodepvar 

		*weights not applied
		estimates clear
		eststo: quietly estpost summarize elec_constraint social_network transport borrow_unable borrow_unwilling high_interest market_access demand_low corruption policy_uncertainty registration_diff high_taxes lawlessness conflicts internet_difficult equipment_shortages constraints_other 
		esttab using Contraints2, tab replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") label nodepvar 


		*Sector of operation
			** Create categories for ISIC definitions
			
			replace s6q1b = 1410 if hhid =="623305-013-150-0008-04" & non_farm_enterprise__id==1
			replace s6q1b = 4782 if hhid =="623305-013-150-0008-04" & non_farm_enterprise__id==2	
			replace s6q1b = 4520 if hhid =="1305100-035-248-0089-18" & non_farm_enterprise__id==1
			replace s6q1b = 4730 if hhid =="1307100-001-051-0086-06" & non_farm_enterprise__id==1
			replace s6q1b = 1040 if hhid =="1307100-007-040-0022-03" & non_farm_enterprise__id==1
			replace s6q1b = 4721 if hhid =="622200-005-039-0041-05" & non_farm_enterprise__id==2	
			replace s6q1b = 4330 if hhid =="6623305-013-150-0009-09" & non_farm_enterprise__id==2	
			replace s6q1b = 4781 if hhid =="6623305-013-150-0009-09" & non_farm_enterprise__id==1	
			replace s6q1b = 0990 if hhid =="6623305-013-150-0009-09" & non_farm_enterprise__id==3	
			replace s6q1b = 4721 if hhid =="623305-020-196-0044-11" & non_farm_enterprise__id==1
			
			replace s6q1b = 4799 if s6q1b == 4888 // this 4digit isic code does not exist anymore
			
			
			gen twodigit=int(s6q1b/100)
			
			gen section ="." 
			replace section = "A" if twodigit>=1 & twodigit<=3
			replace section = "B" if twodigit>=5 & twodigit<=9
			replace section = "C" if twodigit>=10 & twodigit<=33
			replace section = "D" if twodigit==35
			replace section = "E" if twodigit>=36 & twodigit<=39
			replace section = "F" if twodigit>=41 & twodigit<=43
			replace section = "G" if twodigit>=45 & twodigit<=47
			replace section = "H" if twodigit>=49 & twodigit<=53
			replace section = "I" if twodigit>=55 & twodigit<=56
			replace section = "J" if twodigit>=58 & twodigit<=63
			replace section = "K" if twodigit>=64 & twodigit<=66
			replace section = "L" if twodigit==68
			replace section = "M" if twodigit>=69 & twodigit<=75
			replace section = "N" if twodigit>=77 & twodigit<=82
			replace section = "O" if twodigit==84
			replace section = "P" if twodigit==85
			replace section = "Q" if twodigit>=86 & twodigit<=88
			replace section = "R" if twodigit>=90 & twodigit<=93
			replace section = "S" if twodigit>=94 & twodigit<=96
			replace section = "T" if twodigit>=97 & twodigit<=98
			replace section = "U" if twodigit==99
			
			gen section_name = "."
			replace section_name = "Agriculture, forestry and fishing" if section=="A"
			replace section_name = "Mining and quarrying" if section=="B"
			replace section_name = "Manufacturing" if section=="C"
			replace section_name = "Electricity, gas, stream and air conditioning supply" if section=="D"
			replace section_name = "Water supply; sewerage, waste management and remediation activities" if section=="E"
			replace section_name = "Construction" if section=="F"
			replace section_name = "Wholesale and retail; repair of motor vehicles and motorcycles" if section=="G"
			replace section_name = "Transportation and storage" if section=="H"
			replace section_name = "Accommodation and food service actvities" if section=="I"
			replace section_name = "Information and communication" if section=="J"
			replace section_name = "Financial and insurance activities" if section=="K"
			replace section_name = "Real estate activities" if section=="L"
			replace section_name = "Professional, scientific and technical activities" if section=="M"
			replace section_name = "Administrative and support service activities" if section=="N"
			replace section_name = "Public administration and defence; compulsory social security" if section=="O"
			replace section_name = "Education" if section=="P"
			replace section_name = "Human health and social work activities" if section=="Q"
			replace section_name = "Arts, entertainment and recreation" if section=="R"
			replace section_name = "Other service activities" if section=="S"
			replace section_name = "Activities of households as employers; undifferentiated goods - and services - producing activities of households for own use" if section=="T"
			replace section_name = "Activities of extraterritorial organizations and bodies" if section=="U"
			
			gen manufacturing = (section=="C") if section!="." 
			gen retail = (section=="G") if section!="." 
			gen agriculture = (section=="A") if section!="." 


		*Gender of owner
		tab s1q2
		gen male=1 if s1q2==1
		replace male=0 if s1q2==2
		label var male "NFE owner is male"

		*Age
		tab age
		gen age_sq= age*age
		label var age "age of NFE owner"

		*Marital status
		tab s1q6
		gen marital=1 if s1q6==1 | s1q6==2 | s1q6==3  //married or cosensual union
		replace marital=2 if s1q6== 4| s1q6==5 | s1q6==6    //seperated, widowed or divorced
		replace marital=3 if s1q6==7   // never married
		tab s1q6 marital 
		label var marital "marital status of NFE owner"


		tab marital, gen (m)
		rename m1 married
		rename m2 special_single
		rename m3 nev_married
		label var married "NFE owner is married"
		label var special_single "NFE owner is special single"
		label var nev_married "NFE owner has never been married"

		*Relationship to head of household
		gen hhead=1 if s1q5==1
		replace hhead=0 if s1q5!=1
		tab s1q5 hhead
		label var hhead "NFE owner is the head of household"

		*Spouse lives in hhold
		label li s1q7
		gen spouse=1 if s1q7==1
		replace spouse=0 if s1q7==2
		bys hhid: egen spouse_present=max(spouse)
		tab spouse_present
		label var spouse_present "NFE owner spouse is present in the household"


		*Regional controls
		*Regional controls
		tab region
		label li region
		gen ashanti=1 if region==6
		replace ashanti=0 if region!=6
		replace ashanti=. if region==.
		tab region ashanti

		gen northern=1 if region==12 | region==13
		replace northern =0 if region >=1 & region <=11
		replace northern=0 if region >=14 & region <=16
		replace northern=. if region==.
		tab region northern

		label var ashanti "NFE owner is resident in AR"
		label var northern "NFE owner is resident in NR"

		*Residence controls
		label li urbrur
		gen urban=1 if urbrur==1
		replace urban=0 if urbrur==2
		tab urban urbrur
		label var urban "NFE owner is resident in urban area"

		*Religion
		gen muslim=0 if s1q10== 2 | s1q10==3 | s1q10==4 | s1q10==5
		replace muslim=1 if s1q10==6
		replace muslim=. if s1q10==1 | s1q10==7 | s1q10==96
		tab s1q10 muslim
		label var muslim "NFE owner is muslim, as opposed to christian"

		* Does mother live in household
		label li s1q16
		gen mother_present= 1 if s1q16==1
		replace mother_present=0 if s1q16==2 | s1q16==3 | s1q16==4
		replace mother_present=. if s1q16==.
		tab s1q16 mother_present
		label var mother_present "NFE owner mother lives in the household"

		*Does father live in household
		label li s1q12
		gen father_present= 1 if s1q12==1
		replace father_present=0 if s1q12==2 | s1q12==3 | s1q12==4
		replace father_present=. if s1q12==.
		tab s1q12 father_present
		label var father_present "NFE owner father lives in the household"

		*Ethnicity
		gen ethnic= 1 if s1q11== 11   //dagomba
		replace ethnic=2 if s1q11== 1 | s1q11==5 | s1q11 ==6 | s1q11==8 | s1q11==10 | s1q11==12 |s1q11==13 | s1q11==14 | s1q11==15 | s1q11==16     //other northerner
		replace ethnic= 3 if s1q11==2 | s1q11==3 | s1q11== 7 | s1q11==9     //akan
		replace ethnic= 4 if s1q11==4 | s1q11== 17| s1q11==96     // Ewe, Ga or other
		replace ethnic=. if s1q11==.
		tab s1q11 ethnic
		label var ethnic "Ethnicity of NFE owner"

		tab ethnic, gen (e)
		rename e1 dagomba
		rename e2 other_north
		rename e3 akan
		rename e4 ewe_ga_other
		label var dagomba "NFE owner is dagomba"
		label var other_north "NFE owner is from other northern tribe"
		label var akan "NFE owner is akan"
		label var ewe_ga_other "NFE owner is Ewe, Ga or other"

		save "$interm/SVO_Paper2.dta", replace

		*Educational qualification or literacy (languages/calculations; more obs on literacy)
		use "$data/sec2_education.dta", clear

		*Educational attainment
		replace s2q4=. if s2q4==96
		gen education=0 if s2q4==0   //none
		replace education=1 if s2q4==1 | s2q4==2 | s2q4==4    //basic
		replace education=2 if s2q4==3 | s2q4==5 | s2q4==7    // secondary
		replace education=3 if s2q4==6 | s2q4==8 | s2q4==9 | s2q4==10 | s2q4==12   // post secondary
		tab s2q4
		tab education

		*Completed grades
		tab s2q3
		label li s2q3
		gen education2= 1 if s2q3==0 | s2q3==1    // none or pre-school
		replace education2= 2 if s2q3>=11 & s2q3<=16   // primary school
		replace education2= 3 if s2q3>=17 & s2q3<=23    // middle school
		replace education2= 3 if s2q3>=24 & s2q3<=34   // secondary school
		replace education2= 4 if s2q3>=41 & s2q3<=46    // tertiary

		replace education2=. if s2q3==96
		tab s2q3 education2 

		gen sec_plus=1 if education2>=3
		replace sec_plus=0 if education2<3
		tab education2 sec_plus

		*Literacy (english/ french)
		label li s2q10
		gen literate=1 if s2q10==1 | s2q10==2 | s2q10==3
		replace literate=0 if s2q10==4
		tab s2q10 literate

		*Apprenticeship (current/past)
		label li s2q15
		gen apprentice= 1 if s2q15 ==1 | s2q15==2
		replace apprentice=0 if s2q15==3
		tab s2q15 apprentice

		keep hhid indiv cluster education  education2 literate apprentice education2 sec_plus
		label var education "educational attainment"
		label var education "educational grade completed"
		label var literate "can read french or english or both"
		label var apprentice "is an apprentice now or has been in the past"

		merge 1:m hhid indiv using "$interm/SVO_Paper2.dta"
		keep if _merge==3
		drop _merge
		save "$interm/SVO_Paper2.dta", replace

		
	// GENDER ROLES 
		use "$data/sec7_gender.dta", clear
		*Merge with household roster
		merge 1:1 hhid indiv using "$data/sec1_roster.dta"
		drop _merge
		*Only men should work outside the home
		gen men_work= 1 if s7q3==4| s7q3==5
		replace men_work=0 if s7q3==1 | s7q3==2 | s7q3==3
		replace men_work=. if s7q3==.
		tab s7q3 men_work

		*Ok for women to work outside home even if has young child
		gen women_work=1 if s7q4==1 | s7q4==2
		replace women_work=0 if s7q4==3 | s7q4==4 | s7q4==5
		replace women_work=. if s7q4==.
		tab s7q4 women_work

		* Men should perform chores
		gen men_chores=1 if s7q5==1 | s7q5==2
		replace men_chores=0 if s7q5==3 | s7q5==4 | s7q5==5
		replace men_chores=. if s7q5==.
		tab s7q5 men_chores

		*Women should perform chores
		gen women_chores=1 if s7q6==4 | s7q6==5
		replace women_chores=0 if s7q6==1 | s7q6==2 | s7q6==3
		replace women_chores=. if s7q6==.
		tab s7q6 women_chores

		*Men should care for children or dependents
		gen men_care=1 if s7q7==1 | s7q7==2
		replace men_care=0 if s7q7==3 | s7q7==4 | s7q7==5
		replace men_care=. if s7q7==.
		tab s7q7 men_care

		*Women should care for children or dependents
		gen women_care=1 if s7q8==4 | s7q8==5
		replace women_care=0 if s7q8==1 | s7q8==2 | s7q8==3
		replace women_care=. if s7q8==.
		tab s7q8 women_care

		*Women are as capable as men to manage workers
		gen women_capable= 1 if s7q9==1 | s7q9==2
		replace women_capable=0 if s7q9==3 | s7q9==4 | s7q9==5
		replace women_capable=. if s7q9==.
		tab s7q9 women_capable

		*Women are capable intellectually as men as being successful
		gen women_smart=1 if s7q10==1 | s7q10==2
		replace women_smart=0 if s7q10==3 | s7q10==4 | s7q10==5
		replace women_smart=. if s7q10==.
		tab s7q10 women_smart

		*Men should make all decisions
		gen men_decide=1 if s7q11==4 | s7q11==5
		replace men_decide=0 if s7q11==1 | s7q11==2 | s7q11==3
		replace men_decide=. if s7q11==.
		tab s7q11 men_decide

		*Women farmers should grow food
		gen women_food= 1 if s7q12== 4 | s7q12==5
		replace women_food=0 if s7q12==1 | s7q12==2 | s7q12==3
		replace women_food=. if s7q12==.
		tab s7q12 women_food

		*Women grow food for market
		gen women_sale=1 if s7q13==1 | s7q13==2
		replace women_sale=0 if s7q13==3 | s7q13==4 | s7q13==5
		replace women_sale=. if s7q13==.
		tab s7q13 women_sale

		*Only men should grow crops for sale in the market
		gen men_sale=1 if s7q14==4 | s7q14==5
		replace men_sale=0 if s7q14==1 | s7q14==2 | s7q14==3
		replace men_sale=. if s7q14==.
		tab s7q14 men_sale

		*Ok for women to manage men working on land
		gen women_managers=1 if s7q15==1 | s7q15==2
		replace women_managers=0 if s7q15==3 | s7q15==4 | s7q15==5
		replace women_managers=. if s7q15==.
		tab s7q15 women_managers

		*Ok for men to maange women
		gen men_managers=1 if s7q16==4 | s7q16==5
		replace men_managers=0 if s7q16==1 | s7q16==2 | s7q16==3
		replace men_managers=. if s7q16==.
		tab s7q16 men_managers

		local gender men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide women_food women_sale men_sale women_managers men_managers

		*Index Gender norms
		zindex `gender', gen(index_gendernorms)

		*Standardise from 0 to 100
		foreach v of varlist index_gendernorms {
			summ `v', meanonly
			gen `v'_100 = 100*(`v'-`r(min)')/(`r(max)'-`r(min)')
		}
		su index_gendernorms index_gendernorms_100
		label var index_gendernorms "Index of gender norms"
		label var index_gendernorms_100 "Standardized 0-100 index of gender norms"

		*Robustness check using PCA
		pca men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide women_food women_sale men_sale women_managers men_managers
		predict index_gendernorms2, score

		*Standardize data
		foreach v of varlist index_gendernorms2 {
			summ `v', meanonly
			gen `v'_100 = 100*(`v'-`r(min)')/(`r(max)'-`r(min)')
		}
		su index_gendernorms2 index_gendernorms2_100
		label var index_gendernorms2 "PCA scores of Women's Perceptions of Power relations"
		label var index_gendernorms2_100 "Standardized 0-100 PCA scores of Power_Woman"

		bys hhid: egen hh_average_norms=mean(index_gendernorms_100) 
		label var hh_average_norms "Average standardized norms in household"

		keep hhid indiv men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide women_food women_sale men_sale women_managers men_managers index_gendernorms index_gendernorms_100 index_gendernorms2 index_gendernorms2_100 s1q2 hh_average_norms

		*Seperate out responses for men and women
		gen men_index_gendernorms_100 = index_gendernorms_100 if s1q2==1
		gen men_index_gendernorms2_100 = index_gendernorms2_100 if s1q2==1


		gen women_index_gendernorms_100= index_gendernorms_100 if s1q2==2
		gen women_index_gendernorms2_100= index_gendernorms2_100 if s1q2==2


		**After merge, create two columns for men response and women response in each household 
		bys hhid: egen gendernorms_male=max(men_index_gendernorms_100) 

		bys hhid: egen gendernorms_female=max(women_index_gendernorms_100) 

		bys hhid: egen gendernorms2_male=max(men_index_gendernorms2_100) 

		bys hhid: egen gendernorms2_female=max(women_index_gendernorms2_100) 

		*Calculate difference in gender norms (or relati
		gen rel_norms= (gendernorms_female) / (gendernorms_female + gendernorms_male)
		gen rel_norms2= (gendernorms2_female) / (gendernorms2_female + gendernorms2_male)

		merge 1:m hhid indiv using "$interm/SVO_Paper2.dta"
		keep if _merge==3
		drop _merge
		save "$interm/SVO_Paper2.dta", replace

		
	//	Household wealth quintiles
		use "$data/sec9_assets.dta", clear
		*rename assets so code below runs smoothly
		rename s9q1__307 s9q1__305
		rename s9q1__308 s9q1__306
		rename s9q1__310 s9q1__307
		rename s9q1__311 s9q1__308
		rename s9q1__316 s9q1__309
		rename s9q1__317 s9q1__310
		rename s9q1__322 s9q1__311
		rename s9q1__324 s9q1__312
		rename s9q1__326 s9q1__313
		rename s9q1__327 s9q1__314
		rename s9q1__328 s9q1__315
		rename s9q1__329 s9q1__316
		rename s9q1__335 s9q1__317
		rename s9q1__336 s9q1__318
		rename s9q1__338 s9q1__319
		rename s9q1__340 s9q1__320
		rename s9q1__344 s9q1__321
		rename s9q1__346 s9q1__322
		rename s9q1__347 s9q1__323
		rename s9q1__348 s9q1__324
		rename s9q1__352 s9q1__325
		rename s9q1__353 s9q1__326


		forvalues A= 301/326 {
		  gen asset__`A'=0
		  replace asset__`A'=1 if s9q1__`A'>0 & s9q1__`A'~=.
		}

		*Generate PCA with assets
		pca asset_* 
		   predict pca_durables, score
		   lab var pca_durables "Durable Assets (PCA)"
		   sum pca_durables
		xtile WInd = pca_durables, nq(5)
		// Definition and labels of the quintiles
		label define class 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5" 
		label val WInd class
		label var WInd  "Wealth class" 
		tab WInd, gen (Q)
		rename Q1 poorest
		rename Q2 poorer
		rename Q3 middle
		rename Q4 richer
		rename Q5 richest

		label var poorest "poorest wealth quintile"
		label var poorer "poorer wealth quintile"
		label var middle "middle wealth quintile"
		label var richer "richer wealth quintile"
		label var richest "richest wealth quintile"
		label var pca_durables "wealth scores"

		keep hhid pca_durables WInd poorest poorer middle richer richest
		gen poor=1 if poorest==1 | poorer==1
		replace poor=0 if middle==1 | richer==1 | richest==1

		merge 1:m hhid using "$interm/SVO_Paper2.dta"
		keep if _merge==3
		drop _merge
		save "$interm/SVO_Paper2.dta", replace

		*Generate household size and number of children (<5 years; <15years)
		use "$data/sec1_roster.dta", clear
		gen id= _n
		egen hhsize=count(id), by(hhid indiv)
		edit hhid indiv id hhsize
		egen hh_size = total(hhsize), by (hhid)
		edit hhid indiv hhsize hh_size

		*under 5
		gen u5=1 if age<5
		egen und5=count(u5), by(hhid indiv)
		edit hhid u5 und5 age
		egen under5 = total(und5), by (hhid)
		replace under5=. if age==.
		edit hhid age u5 und5 under5

		*under15
		gen u15=1 if age<15
		egen und15=count(u15), by(hhid indiv)
		edit hhid u15 und15 age
		egen under15 = total(und15), by (hhid)
		replace under15=. if age==.
		edit hhid age under5 under15 hh_size

		collapse hh_size under5 under15, by (hhid)

		merge 1:m hhid using "$interm/SVO_Paper2.dta"
		keep if _merge==3
		drop _merge
		save "$interm/SVO_Paper2.dta", replace


	//	PERSONALITY TRAITS 
		use "$data/sec8_personality.dta", clear
		*Construction from Laajaj, Rachid and Karen Macours. 2017

			*** Calculate naive scores (without acquiescence bias correction)
			* reverse code s8q1 and s8q3
			replace s8q1=. if s8q1>5
			replace s8q2=. if s8q2>5
			replace s8q3=. if s8q3>5
			recode s8q1 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q3 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen impulsive1 = rowmean(s8q1 s8q2 s8q3)
			label variable impulsive1 "Personality trait - impulsiveness (naive)"
			tab impulsive1		

			replace s8q4=. if s8q4>5
			replace s8q21=. if s8q21>5
			egen wk_central1 = rowmean(s8q4 s8q21)
			label variable wk_central1 "Personality trait - work centrality (naive)"
			tab wk_central1

			replace s8q5=. if s8q5>5
			replace s8q6=. if s8q6>5
			egen tenacity1 = rowmean(s8q5 s8q6)
			label variable tenacity1 "Personality trait - tenacity (naive)"
			tab tenacity1

			* reverse code s8q8 and s8q9
			replace s8q7=. if s8q7>5
			replace s8q8=. if s8q8>5
			replace s8q9=. if s8q9>5
			recode s8q8 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q9 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen polychronic1 = rowmean(s8q7 s8q8 s8q9)
			label variable polychronic1 "Personality trait - polychronicity (naive)"
			tab polychronic1

			* reverse code s8q12
			replace s8q10=. if s8q10>5
			replace s8q11=. if s8q11>5
			replace s8q12=. if s8q12>5
			recode s8q10 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q11 (1=5) (2=4) (3=3) (4=2) (5=1)

			egen locctl1 = rowmean(s8q10 s8q11 s8q12)
			label variable locctl1 "Personality trait - locus of control (naive)"
			tab locctl1

			replace s8q13=. if s8q13>5
			replace s8q14=. if s8q14>5
			replace s8q15=. if s8q15>5
			replace s8q16=. if s8q16>5
			replace s8q17=. if s8q17>5
			egen achievemt1 = rowmean(s8q13 s8q14 s8q15 s8q16 s8q17)
			label variable achievemt1 "Personality trait - achievement (naive)"
			tab achievemt1

			replace s8q18=. if s8q18>5
			replace s8q19=. if s8q19>5
			replace s8q20=. if s8q20>5
			egen pow_mot1 = rowmean(s8q18 s8q19 s8q20)
			label variable pow_mot1 "Personality trait - power motivation (naive)"
			tab pow_mot1

			replace s8q22=. if s8q22>5
			generate organized1 = s8q22
			label variable organized1 "Personality trait - organized person (naive)"
			tab organized1

			replace s8q23=. if s8q23>5
			replace s8q24=. if s8q24>5
			replace s8q25=. if s8q25>5
			replace s8q26=. if s8q26>5
			replace s8q27=. if s8q27>5
			replace s8q28=. if s8q28>5
			* reverse code s8q24 s8q26 and s8q27
			recode s8q24 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q26 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q27 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen optimism1 = rowmean(s8q23 s8q24 s8q25 s8q26 s8q27 s8q28)
			label variable optimism1 "Personality trait - optimism (naive)"
			tab optimism1


		merge 1:m hhid indiv using "$interm/SVO_Paper2.dta"
		keep if _merge==3
		drop _merge
		save "$interm/SVO_Paper2.dta", replace

		*Create column for women gender norms in each hhold
		gen temp=index_gendernorms_100 if male==0 
				tab temp
				bys hhid: egen female_gnorms=max(temp)
				tab female_gnorms, miss 
				drop temp
				
				replace female_gnorms=. if index_gendernorms_100==.
				
		gen temp=index_gendernorms_100 if male==1
				tab temp
				bys hhid: egen male_gnorms=max(temp)
				tab male_gnorms, miss 
				drop temp

				replace male_gnorms=. if index_gendernorms_100==.
			
		*Average of male and female respondent in household
		egen average_gnorms= rowmean(female_gnorms male_gnorms)
		replace average_gnorms=. if female_gnorms==. | male_gnorms==.

		*Difference between male and female scores in households
		gen diff_gnorms= male_gnorms- female_gnorms

		save "$interm/SVO_Paper2.dta", replace

		*EA average of responses
		use "$interm/SVO_Paper2.dta"
		collapse index_gendernorms_100, by (ea_code)
		rename index_gendernorms_100 ea_gnorms

		merge 1:m ea_code using "$interm/SVO_Paper2.dta"
		drop _merge
		replace ea_gnorms=. if index_gendernorms_100==.
		save "$interm/SVO_Paper2.dta", replace


	//	OTHER LABOR VARIABLES
		 *Products were not (mainly/only) for household use
		use "$data/sec3_labor.dta", clear
		keep if s3q0 == 1 // working on the sample of working age adults (>= 15yo)

		gen employed = (s3q1==1 | s3q3==1 | s3q4==1 | s3q5==1 |  ((s3q7==1 | s3q8==1) & (s3q10!=3 & s3q10!=4)) | ///
			((s3q11==1 | s3q12==1) & (s3q15!=3 & s3q15!=4)) | (s3q16==1 & (s3q21!=3 & s3q21!=4))) 
		*During the last four weeks,  [NAME] did something to find a paid job
		*During the last four weeks, [Name] tried to start a business
		gen unemployed = ((s3q22==1 | s3q23==1))

		gen not_in_workforce = (unemployed==0 & employed==0)

		gen in_ag_not_in_workforce = (s3q10 ==3 | s3q10==4 | s3q15 ==3 | s3q15==4 | s3q21 ==3 | s3q21==4) if not_in_workforce==1
		gen inactive_not_in_workforce = (in_ag_not_in_workforce==0) if not_in_workforce==1
				
				
		label var employed "Being employed"
		label var unemployed "Being unemployed"
		label var not_in_workforce "Not being in the workforce"
		label var in_ag_not_in_workforce "Not being in the workforce but involved in agricultural activities for hh use"
		label var in_ag_not_in_workforce "Not being in the workforce and being inactive"

		gen employ_cats1=1 if employed==1
		replace employ_cats1=2 if unemployed==1
		replace employ_cats1=3 if not_in_workforce==1
		tab employ_cats1
				
		** 2. SECOND LAYER: Define categories of employment based on the main activity (mutually exclusive)

		*Self employment
		*Main job is in own business or farming activity
		*In a business or farm operated by a household member
		gen hh_employment = (s3q35==1 | s3q35==2) 

		*Wage employment
		*Worked As an employee for someone else or as an apprentice, trainee, intern
		gen wage_employment = (s3q35==3 | s3q35==4)

		gen employ_cats2=1 if hh_employment==1
		replace employ_cats2=0 if wage_employment==1

		gen wage_emp=0 if hh_employment==1
		replace wage_emp=1 if wage_employment==1

				
		label var hh_employment "Working as self-employed or for someone else in the household"
		label var wage_employment "Working as an employee, trainee or intern for someone else"

		keep hhid indiv employ_cats1 employ_cats2 employed unemployed not_in_workforce in_ag_not_in_workforce ///
			 inactive_not_in_workforce hh_employment wage_employment wage_emp
		merge 1:m hhid indiv using "$interm/SVO_Paper2.dta"
		drop _merge

		gen REGION=1 if region==6
		replace REGION=0 if region==12 | region==13
		tab region REGION


	//	Taxonomy on business performance (Table 2 + Figures 1)
		*All workers
		gen workers1= 1 if total_emp==0
		replace workers1=2 if total_emp==1
		replace workers1=3 if total_emp>=2
		replace workers1=. if total_emp==.

		*Paid workers, all
		gen workers2= 1 if paid_emp==0   //no worker
		replace workers2=2 if paid_emp==1   //1 worker
		replace workers2=3 if paid_emp>=2    //2+ workers
		replace workers2=. if paid_emp==.

		*Unpaid workers
		gen workers3= 1 if unpaid_emp==0
		replace workers3=2 if unpaid_emp==1
		replace workers3=3 if unpaid_emp>=2
		replace workers3=. if unpaid_emp==.

		
	//	Save Final Analytical Datafile
		save "$interm/SVO_Paper2.dta", replace



**************************************************END**********************************************************************




