******************************************************************************************************************
*****	Household Business Performance in Ghana: The Role of Personality Traits and Gender Role Attitudes	******
******************************	Before Running this Dofile, please ensure all the ********************************
******************************	Data Preparatory Dofiles have be Implemented  ************************************	

****************************************** TABLES ************************************************

	//	Set up System
		set more off
		capture set max_memory 500M /* for stata 12 */
		capture set mem 500M		
		cap log close
		clear all

		
	//	Call the Final Analytical Datafile
		use "$interm/SVO_Paper2.dta", clear	

		
	//	First, Set the Analytical Sample 
		reg avg_revenue index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 organized1 ///
			optimism1 male age age_sq sec_plus married muslim poor under5 under15 registered ///
			ent_tenure NFE_number trad_market commercial roadside mobile sep_exp past_exp credit_operate NFE_acct covid_support ///
			NFE_literacy social_media business_assoc subsist manufacturing retail urban ashanti, vce(cluster cluster)
			
			/* Note that in the first regression above, nev_married was used to generate the analytical sample*/
		
		keep if e(sample)


	//	Table 2. Descriptive Statistics for Businesses, by Gender of Owner (Analytic sample)
		global des_vars avg_revenueGHC profitGHC index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 ///
			   pow_mot1 organized1 optimism1 male age sec_plus married muslim under5 under15 poor registered ent_tenure NFE_number home ///
			   trad_market commercial roadside mobile sep_exp past_exp credit_operate NFE_acct covid_support NFE_literacy social_media ///
			   business_assoc subsist manufacturing retail urban ashanti

		** Pooled 
		estimates clear
		eststo: quietly estpost summarize $des_vars  [aw= hhweight]
		esttab using "$tables\Table 2 - Pooled Sample", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 
		
		** Gender 
		estimates clear
		sort male
		by male: eststo: quietly estpost summarize $des_vars  [aw= hhweight]
				esttab using "$tables\Table 2 - Women and Men", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		**	t Test 
		estimates clear
		estpost ttest  $des_vars, by (male)
		esttab using "$tables\Table 2 - t Tests", csv replace wide starlevels( * 0.10 ** 0.05 *** 0.010)

	//	Table 3. Descriptive Statistics for Businesses, by Business Registration Status 

		** Formality Status 
		estimates clear
		sort registered
		by registered: eststo: quietly estpost summarize $des_vars  [aw= hhweight]
				esttab using "$tables\Table 3 - Informal vs Formal", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		**	t Test 
		estimates clear
		estpost ttest  $des_vars, by (registered)
		esttab using "$tables\Table 3 - t Tests", csv replace wide starlevels( * 0.10 ** 0.05 *** 0.010)


	//	Figure 1. Type and number of workers by registration status
		**	Informal Businesses 
		clear matrix
		matrix input ones = (1\1\1)	//Generate a matrix of ones of 5row 1col
			tabulate workers2 male [aw=hhweight] if registered==0, col matcell(F1A)
			matrix rowtot1 = F1A'*ones
			matrix rowpct1 = ((inv(diag(rowtot1)))*F1A')*100
			matrix def F1A=rowpct1'
			matrix list F1A

			tabulate workers3 male [aw=hhweight] if registered==0,  matcell(F1B)
			matrix rowtot2 = F1B'*ones
			matrix rowpct2 = ((inv(diag(rowtot2)))*F1B')*100
			matrix def F1B=rowpct2'
			matrix list F1B
			
			mat F1C = F1A, F1B
			matlist F1C
			
			putexcel set "$tables\Figures 1-3", sheet("F1") mod
			putexcel C5=matrix(F1C[1...,1...])		
	
	
		**	Formal Businesses 
		clear matrix
		matrix input ones = (1\1\1)	//Generate a matrix of ones of 5row 1col
			tabulate workers2 male [aw=hhweight] if registered==1, col matcell(F1D)
			matrix rowtot1 = F1D'*ones
			matrix rowpct1 = ((inv(diag(rowtot1)))*F1D')*100
			matrix def F1D=rowpct1'
			matrix list F1D

			tabulate workers3 male [aw=hhweight] if registered==1,  matcell(F1E)
			matrix rowtot2 = F1E'*ones
			matrix rowpct2 = ((inv(diag(rowtot2)))*F1E')*100
			matrix def F1E=rowpct2'
			matrix list F1E
			
			mat F1F = F1D, F1E
			matlist F1F
			
			putexcel set "$tables\Figures 1-3", sheet("F1") mod
			putexcel C15=matrix(F1F[1...,1...])	
				
				
	//	Figure 2. Informal business performance by number of employees and gender of 
		**	Paid Employees
			clear matrix	
			foreach var of varlist revenueGHC profitGHC {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 1 & registered==0
						matrix Q1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 2 & registered==0
						matrix Q2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 3 & registered==0
						matrix Q3 = r(mean)

					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 1 & registered==0
						matrix Q4 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 2 & registered==0
						matrix Q5 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 3 & registered==0
						matrix Q6 = r(mean)
							
						mat M = Q1, Q2, Q3 \ Q4, Q5, Q6
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat F2A=nullmat(F2A)\(`var'`m')	
						}			
					}
				matlist F2A'

				mat F2A = F2A'
				
			putexcel set "$tables\Figures 1-3", sheet("F2") mod
			putexcel C5=matrix(F2A[1...,1...])	
			
		**	Unpaid Employees
			clear matrix	
			foreach var of varlist revenueGHC profitGHC {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 1 & registered==0
						matrix Q1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 2 & registered==0
						matrix Q2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 3 & registered==0
						matrix Q3 = r(mean)

					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 1 & registered==0
						matrix Q4 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 2 & registered==0
						matrix Q5 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 3 & registered==0
						matrix Q6 = r(mean)
						
						mat M = Q1, Q2, Q3 \ Q4, Q5, Q6
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat F2B=nullmat(F2B)\(`var'`m')	
						}			
					}
				matlist F2B'
				mat F2B = F2B'
										
			putexcel set "$tables\Figures 1-3", sheet("F2") mod
			putexcel C15=matrix(F2B[1...,1...])	


		//	Figure 3. Formal business performance by number of employees and gender of 
			**	Paid Employees			
			clear matrix	
			foreach var of varlist revenueGHC profitGHC {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 1 & registered==1
						matrix Q1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 2 & registered==1
						matrix Q2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers2 == 3 & registered==1
						matrix Q3 = r(mean)

					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 1 & registered==1
						matrix Q4 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 2 & registered==1
						matrix Q5 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers2 == 3 & registered==1
						matrix Q6 = r(mean)
						
						mat M = Q1, Q2, Q3 \ Q4, Q5, Q6
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat F3A=nullmat(F3A)\(`var'`m')	
						}			
					}
				mat F3A = F3A'
				
			putexcel set "$tables\Figures 1-3", sheet("F3") mod
			putexcel C5=matrix(F3A[1...,1...])	
			
		**	Unpaid Employees
			clear matrix	
			foreach var of varlist revenueGHC profitGHC {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 1 & registered==1
						matrix K1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 2 & registered==1
						matrix K2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & workers3 == 3 & registered==1
						matrix K3 = r(mean)

					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 1 & registered==1
						matrix K4 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 2 & registered==1
						matrix K5 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & workers3 == 3 & registered==1
						matrix K6 = r(mean)
						
						mat M = K1, K2, K3 \ K4, K5, K6
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat F3B=nullmat(F3B)\(`var'`m')	
						}			
					}
				matlist F3B'
				mat F3B = F3B'
										
			putexcel set "$tables\Figures 1-3", sheet("F3") mod
			putexcel C15=matrix(F3B[1...,1...])		


	//	REGRESSION RESULTS

		global pool_xvars age age_sq male sec_plus married muslim poor under5 under15 registered ent_tenure NFE_number trad_market ///
					 commercial roadside mobile sep_exp past_exp credit_operate NFE_acct covid_support NFE_literacy social_media ///
					 business_assoc subsist manufacturing retail urban ashanti
		global sex_xvars age age_sq sec_plus married muslim poor under5 under15 registered ent_tenure NFE_number trad_market ///
					 commercial roadside mobile sep_exp past_exp credit_operate NFE_acct covid_support NFE_literacy social_media ///
					 business_assoc subsist manufacturing retail urban ashanti
		 global p_traits impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 organized1 optimism1
	
	
	//	Table 4. Linear regression of Business Performance, without Gender role attitudes and personality traits 
		estimates clear
		reg avg_revenue $pool_xvars, vce(cluster cluster)
		estimates store m1

		reg avg_revenue $pool_xvars if male==0, vce(cluster cluster)
		estimates store m2

		reg avg_revenue $pool_xvars if male==1, vce(cluster cluster)
		estimates store m3

		reg profit $pool_xvars, vce(cluster cluster)
		estimates store m4

		reg profit $pool_xvars if male==0, vce(cluster cluster)
		estimates store m5 

		reg profit $pool_xvars if male==1, vce(cluster cluster)
		estimates store m6

		outreg2 [m1 m2 m3 m4 m5 m6] using "$tables/Table 4 - Labor Pdtivity - No GN and PT.xls", replace symbol(***, **, *) dec(3) stat(coef tstat)


	//	Table 5. Linear regressions- Effects of Gender role attitudes and Personality traits on Business Performance (pooled sample)

		estimates clear
		reg avg_revenue index_gendernorms_100, vce(cluster cluster)
		estimates store m1

		reg avg_revenue index_gendernorms_100 $pool_xvars, vce(cluster cluster)
		estimates store m2
		
		reg avg_revenue index_gendernorms_100 $p_traits $pool_xvars, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg avg_revenue c.index_gendernorms_100##c.impulsive1 $pool_xvars, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg avg_revenue c.index_gendernorms_100##c.wk_central1 $pool_xvars, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg avg_revenue c.index_gendernorms_100##c.tenacity1 $pool_xvars, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg avg_revenue  c.index_gendernorms_100##c.polychronic1 $pool_xvars, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg avg_revenue  c.index_gendernorms_100##c.locctl1 $pool_xvars, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg avg_revenue  c.index_gendernorms_100##c.achievemt1 $pool_xvars, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg avg_revenue  c.index_gendernorms_100##c.pow_mot1 $pool_xvars, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg avg_revenue  c.index_gendernorms_100##c.organized1 $pool_xvars, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg avg_revenue  c.index_gendernorms_100##c.optimism1 $pool_xvars, vce(cluster cluster) 
		estimates store m12
		
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 5 - Pooled Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) 

		
	//	Table 6. Linear regressions- Effects of Gender role attitudes and Personality traits on Business Performance (Women sample)
	
		estimates clear
		reg avg_revenue index_gendernorms_100 if male==0, vce(cluster cluster)
		estimates store m1

		reg avg_revenue index_gendernorms_100 $sex_xvars if male==0, vce(cluster cluster)
		estimates store m2
		
		reg avg_revenue index_gendernorms_100 $p_traits $sex_xvars if male==0, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg avg_revenue c.index_gendernorms_100##c.impulsive1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg avg_revenue c.index_gendernorms_100##c.wk_central1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg avg_revenue c.index_gendernorms_100##c.tenacity1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg avg_revenue  c.index_gendernorms_100##c.polychronic1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg avg_revenue  c.index_gendernorms_100##c.locctl1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg avg_revenue  c.index_gendernorms_100##c.achievemt1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg avg_revenue  c.index_gendernorms_100##c.pow_mot1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg avg_revenue  c.index_gendernorms_100##c.organized1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg avg_revenue  c.index_gendernorms_100##c.optimism1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m12
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 6 - Women Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) drop ($sex_xvars)


	//	Table 7. Linear regressions- Effects of Gender role attitudes and Personality traits on Business Performance (Men sample)
		estimates clear
		reg avg_revenue index_gendernorms_100 if male==1, vce(cluster cluster)
		estimates store m1

		reg avg_revenue index_gendernorms_100 $sex_xvars if male==1, vce(cluster cluster)
		estimates store m2
		
		reg avg_revenue index_gendernorms_100 $p_traits $sex_xvars if male==1, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg avg_revenue c.index_gendernorms_100##c.impulsive1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg avg_revenue c.index_gendernorms_100##c.wk_central1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg avg_revenue c.index_gendernorms_100##c.tenacity1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg avg_revenue  c.index_gendernorms_100##c.polychronic1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg avg_revenue  c.index_gendernorms_100##c.locctl1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg avg_revenue  c.index_gendernorms_100##c.achievemt1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg avg_revenue  c.index_gendernorms_100##c.pow_mot1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg avg_revenue  c.index_gendernorms_100##c.organized1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg avg_revenue  c.index_gendernorms_100##c.optimism1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m12
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 7 - Men Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) drop ($sex_xvars)

		
	//	Table 8. Effects of Gender role attitudes and Personality traits on Profit (pooled sample)

		estimates clear
		reg profit index_gendernorms_100, vce(cluster cluster)
		estimates store m1

		reg profit index_gendernorms_100 $pool_xvars, vce(cluster cluster)
		estimates store m2
		
		reg profit index_gendernorms_100 $p_traits $pool_xvars, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg profit c.index_gendernorms_100##c.impulsive1 $pool_xvars, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg profit c.index_gendernorms_100##c.wk_central1 $pool_xvars, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg profit c.index_gendernorms_100##c.tenacity1 $pool_xvars, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg profit  c.index_gendernorms_100##c.polychronic1 $pool_xvars, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg profit  c.index_gendernorms_100##c.locctl1 $pool_xvars, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg profit  c.index_gendernorms_100##c.achievemt1 $pool_xvars, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg profit  c.index_gendernorms_100##c.pow_mot1 $pool_xvars, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg profit  c.index_gendernorms_100##c.organized1 $pool_xvars, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg profit  c.index_gendernorms_100##c.optimism1 $pool_xvars, vce(cluster cluster) 
		estimates store m12	
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 8 - Pooled Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) drop ($pool_xvars)

		
	//	Table 9. Effects of Gender role attitudes and Personality traits on Profit (Women sample)
		estimates clear
		reg profit index_gendernorms_100 if male==0, vce(cluster cluster)
		estimates store m1

		reg profit index_gendernorms_100 $sex_xvars if male==0, vce(cluster cluster)
		estimates store m2
		
		reg profit index_gendernorms_100 $p_traits $sex_xvars if male==0, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg profit c.index_gendernorms_100##c.impulsive1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg profit c.index_gendernorms_100##c.wk_central1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg profit c.index_gendernorms_100##c.tenacity1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg profit  c.index_gendernorms_100##c.polychronic1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg profit  c.index_gendernorms_100##c.locctl1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg profit  c.index_gendernorms_100##c.achievemt1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg profit  c.index_gendernorms_100##c.pow_mot1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg profit  c.index_gendernorms_100##c.organized1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg profit  c.index_gendernorms_100##c.optimism1 $sex_xvars if male==0, vce(cluster cluster) 
		estimates store m12
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 9 - Women Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) drop ($sex_xvars)


	//	Table 10. Effects of Gender role attitudes and Personality traits on Profit (Men sample)
		estimates clear
		reg profit index_gendernorms_100 if male==1, vce(cluster cluster)
		estimates store m1

		reg profit index_gendernorms_100 $sex_xvars if male==1, vce(cluster cluster)
		estimates store m2
		
		reg profit index_gendernorms_100 $p_traits $sex_xvars if male==1, vce(cluster cluster)
		estimates store m3

		*Impulsiveness
		reg profit c.index_gendernorms_100##c.impulsive1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg profit c.index_gendernorms_100##c.wk_central1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg profit c.index_gendernorms_100##c.tenacity1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg profit  c.index_gendernorms_100##c.polychronic1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg profit  c.index_gendernorms_100##c.locctl1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg profit  c.index_gendernorms_100##c.achievemt1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg profit  c.index_gendernorms_100##c.pow_mot1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg profit  c.index_gendernorms_100##c.organized1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg profit  c.index_gendernorms_100##c.optimism1 $sex_xvars if male==1, vce(cluster cluster) 
		estimates store m12
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 10 - Men Sample - PT and GRA.xls", replace symbol(***, **, *) stat(coef tstat) dec(3) drop ($sex_xvars)



	//	Table A1- Differences in perceptions of gender roles by all men and women surveyed (weighted)
		global gender_roles men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide ///
							women_food women_sale men_sale women_managers men_managers
		
		sort male
		by male: eststo: quietly estpost summarize $gender_roles [aweight= hhweight]
			esttab using "$tables\Table A1 - Differences in PTs", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") label nodepvar 
		
		estimates clear
		estpost ttest $gender_roles, by (male)
			esttab using "$tables\Table A1 - t Test", csv replace cells("b(fmt(2) label(Mean)) p(fmt(2) label(P-value))") label nodepvar 


